package	jp.co.sds_corp.report.source;

import jp.co.sds_corp.util.common.CmnProperty;
import jp.co.sds_corp.util.config.IConfiguration;

/**
{@link ISource}を生成するFactoryクラスです。
以下の形式のXMLファイル{@link ISource}を生成します。
<pre>
&lt;Source
	language="JavaScript"&gt;
&lt;/Source&gt;
</pre>
languageの代わりにclass属性が指定された場合は、指定されたオブジェクトを生成します。
<pre>
&lt;Script
	class="<EM>foo.bar.class</EM>"&gt;
&lt;/Script&gt;
</pre>
*/
public class SourceFactory
{
	/**
	* 設定情報により、{@link ISource}を生成します。
	* @param	config	設定情報
	* @return	生成された{@link ISource}
	*/
	public static ISource createSource( IConfiguration config )
		throws Exception
	{
		return createSource( config, null );
	}

	/**
	* 設定情報により、{@link ISource}を生成します。
	* @param	config	設定情報
	* @param	prop	properties
	* @return	生成された{@link ISource}
	*/
	public static ISource createSource( IConfiguration config, CmnProperty prop )
		throws Exception
	{
		ISource ret = null;
		String cls = config.getAttributes().get( "class", null );
		if ( cls != null ) {
			ret = (ISource )Class.forName( cls ).newInstance();
		}
		if ( ret == null ) {
			throw( new IllegalArgumentException( "class not defined." ));
		}
		ret.setProperty( prop );
		ret.init( config );
		return ret;
	}
}
